==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/ServiceAuthenticationConfigurationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Authentication configuration information
 * @property audience The audience url for the service
 * @property authority The authority url for the service
 * @property smartProxyEnabled If the SMART on FHIR proxy is enabled
 */
public data class ServiceAuthenticationConfigurationInfoArgs(
    public val audience: Output<String>? = null,
    public val authority: Output<String>? = null,
    public val smartProxyEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs =
        com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs.builder()
            .audience(audience?.applyValue({ args0 -> args0 }))
            .authority(authority?.applyValue({ args0 -> args0 }))
            .smartProxyEnabled(smartProxyEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceAuthenticationConfigurationInfoArgs].
 */
@PulumiTagMarker
public class ServiceAuthenticationConfigurationInfoArgsBuilder internal constructor() {
    private var audience: Output<String>? = null

    private var authority: Output<String>? = null

    private var smartProxyEnabled: Output<Boolean>? = null

    /**
     * @param value The audience url for the service
     */
    @JvmName("hglbtpjiurnfkney")
    public suspend fun audience(`value`: Output<String>) {
        this.audience = value
    }

    /**
     * @param value The authority url for the service
     */
    @JvmName("teevrhkkkdooxhjf")
    public suspend fun authority(`value`: Output<String>) {
        this.authority = value
    }

    /**
     * @param value If the SMART on FHIR proxy is enabled
     */
    @JvmName("moscxhlshijdtkxy")
    public suspend fun smartProxyEnabled(`value`: Output<Boolean>) {
        this.smartProxyEnabled = value
    }

    /**
     * @param value The audience url for the service
     */
    @JvmName("vrsyptimmrhbygpi")
    public suspend fun audience(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audience = mapped
    }

    /**
     * @param value The authority url for the service
     */
    @JvmName("ptdlrqujkdicxihm")
    public suspend fun authority(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authority = mapped
    }

    /**
     * @param value If the SMART on FHIR proxy is enabled
     */
    @JvmName("khvcellogorlmrru")
    public suspend fun smartProxyEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.smartProxyEnabled = mapped
    }

    internal fun build(): ServiceAuthenticationConfigurationInfoArgs =
        ServiceAuthenticationConfigurationInfoArgs(
            audience = audience,
            authority = authority,
            smartProxyEnabled = smartProxyEnabled,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/ServiceAuthenticationConfigurationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Authentication configuration information
 * @property audience The audience url for the service
 * @property authority The authority url for the service
 * @property smartProxyEnabled If the SMART on FHIR proxy is enabled
 */
public data class ServiceAuthenticationConfigurationInfoArgs(
    public val audience: Output<String>? = null,
    public val authority: Output<String>? = null,
    public val smartProxyEnabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs =
        com.pulumi.azurenative.healthcareapis.inputs.ServiceAuthenticationConfigurationInfoArgs.builder()
            .audience(audience?.applyValue({ args0 -> args0 }))
            .authority(authority?.applyValue({ args0 -> args0 }))
            .smartProxyEnabled(smartProxyEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceAuthenticationConfigurationInfoArgs].
 */
@PulumiTagMarker
public class ServiceAuthenticationConfigurationInfoArgsBuilder internal constructor() {
    private var audience: Output<String>? = null

    private var authority: Output<String>? = null

    private var smartProxyEnabled: Output<Boolean>? = null

    /**
     * @param value The audience url for the service
     */
    @JvmName("eygpjvycsqejudkp")
    public suspend fun audience(`value`: Output<String>) {
        this.audience = value
    }

    /**
     * @param value The authority url for the service
     */
    @JvmName("crpbqaqgsiccbaae")
    public suspend fun authority(`value`: Output<String>) {
        this.authority = value
    }

    /**
     * @param value If the SMART on FHIR proxy is enabled
     */
    @JvmName("uerslederpcskijc")
    public suspend fun smartProxyEnabled(`value`: Output<Boolean>) {
        this.smartProxyEnabled = value
    }

    /**
     * @param value The audience url for the service
     */
    @JvmName("hxrmreopqeahuiqd")
    public suspend fun audience(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audience = mapped
    }

    /**
     * @param value The authority url for the service
     */
    @JvmName("lrjraimkfhhrkmpj")
    public suspend fun authority(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authority = mapped
    }

    /**
     * @param value If the SMART on FHIR proxy is enabled
     */
    @JvmName("oilqrndndafyqeje")
    public suspend fun smartProxyEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.smartProxyEnabled = mapped
    }

    internal fun build(): ServiceAuthenticationConfigurationInfoArgs =
        ServiceAuthenticationConfigurationInfoArgs(
            audience = audience,
            authority = authority,
            smartProxyEnabled = smartProxyEnabled,
        )
}
